{config, pkgs, ...}:
let
  base = import ../options.nix {};
in {
  imports = [
    ../variables.nix
  ];

  system.stateVersion = "${base.stateVersion}";

  nix.settings.experimental-features = [
    "nix-command"
    "flakes"
  ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.networkmanager.enable = true;  # Easiest to use and most distros use this by default.

  # Set your time zone.
  time.timeZone = "Europe/Amsterdam";

  i18n.defaultLocale = "en_GB.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "uk";
    # useXkbConfig = true; # use xkb.options in tty.
  };

  services.qemuGuest.enable = config.vmGuest;
  services.spice-vdagentd.enable = config.vmGuest;

  security.rtkit.enable = true; # Enable real-time scheduling for audio applications.

  services = {
    pipewire = {
      enable = true;
      pulse.enable = true;
      alsa.enable = true;
      alsa.support32Bit = true; # Enable 32-bit support if needed.
    };

    openssh = {
      enable = true;
      settings = {
        PasswordAuthentication = true; # Enable password authentication.
        PermitRootLogin = "yes"; # Allow root login (not recommended for production).
      };
    };

    libinput.enable = true;
  };

  environment.systemPackages = with pkgs; [
    vim wget curl git emacs
  ];
}
