{pkgs, ...}: let
  user = import ../data/user.nix {};
in{
  programs.firefox = {
    enable = true;

    policies = {
      CaptivePortal = false;
      DisablePocket = true;
      DisableTelemetry = true;
      DisableFirefoxStudies = true;
      FirefoxHome = {
        Pocket = false;
        Snippets = false;
      };
    };

    profiles = {
      default = {
        isDefault = true;

        search = {
          default = "ddg";
          force = true;
          privateDefault = "ddg";
        };

        settings = {
          # disable warning when editing about:config
          "browser.aboutConfig.showWarning" = false;
          # webgpu
          "dom.webgpu.enabled" = true;
          "gfx.webrender.all" = true;
          "signon.rememberSignons" = false;
          # mozilla syncserver
          "identity.sync.tokenserver.uri" = "https://nirgendswo.com:8001/1.0/sync/1.5";
          "services.sync.username" = user.email;
          "browser.startup.page" = 3; # resume previous session
          "browser.startup.homepage" = "about:home";
          "browser.toolbars.bookmarks.visibility" = "never";

          # hardening
          "browser.newtabpage.enabled" = false;
          "browser.newtabpage.activity-stream.feeds.telemetry" = false;
          "browser.newtabpage.activity-stream.telemetry" = false;
          "browser.newtabpage.activity-stream.feeds.snippets" = false;
          "browser.newtabpage.activity-stream.feeds.section.topstories" = false;
          "browser.newtabpage.activity-stream.showSponsoredTopSites" = false;
          "browser.newtabpage.activity-stream.showSponsored" = false;
          "browser.newtabpage.activity-stream.feeds.discoverystreamfeed" = false;
          "browser.newtabpage.activity-stream.default.sites" = "";
          "browser.newtab.preload" = false;
          "geo.provider.network.url" = "https://location.services.mozilla.com/v1/geolocate?key=%MOZILLA_API_KEY%";
          "geo.provider.ms-windows-location" = false;
          "geo.provider.use_corelocation" = false;
          "geo.provider.use_gpsd" = false;
          "geo.provider.use_geoclue" = false;
          "browser.region.network.url" = "";
          "browser.region.update.enabled" = false;
          "intl.accept_languages" = "en-US,en-GB,en";
          "javascript.use_us_language_locale" = true;
          "app.update.auto" = false;

          "extensions.discover.enabled" = false;
          "extensions.htmlaboutaddons.recommendations.enabled" = false;
          "extenisons.getAddons.showPane" = false;

          "datareporting.healthreport.uploadEnabled" = false;
          "datareporting.policy.dataSubmissionEnabled" = false;
          "toolkit.telemetry.enabled" = false;
          "toolkit.telemetry.unified" = false;
          "toolkit.telemetry.server" = "data:,";
          "toolkit.telemetry.archive.enabled" = false;
          "toolkit.telemetry.newProfilePing.enabled" = false;
          "toolkit.telemetry.shutdownPingSender.enabled" = false;
          "toolkit.telemetry.updatePing.enabled" = false;
          "toolkit.telemetry.bhrPing.enabled" = false;
          "toolkit.telemetry.firstShutdownPing.enabled" = false;
          "toolkit.telemetry.coverage.opt-out" = true;
          "toolkit.coverage.opt-out" = true;
          "beacon.enabled" = false;

          "app.shield.optoutstudies.enabled" = false;

          "captivedetect.canonicalURL" = "";
          "network.captive-portal-service.enabled" = false;
          "network.connectivity-service.enabled" = false;

          "browser.safebrowsing.malware.enabled" = false;
          "browser.safebrowsing.phishing.enabled" = false;
          "browser.safebrowsing.blockedURIs.enabled" = false;
          "browser.safebrowsing.provider.google4.gethashURL" = "";
          "browser.safebrowsing.provider.google4.updateURL" = "";
          "browser.safebrowsing.provider.google4.dataSharingURL" = "";
          "browser.safebrowsing.provider.google.gethashURL" = "";
          "browser.safebrowsing.provider.google.updateURL" = "";

          "browser.safebrowsing.downloads.enabled" = false;
          "browser.safebrowsing.downloads.remote.enabled" = false;
          "browser.safebrowsing.downloads.remote.url" = "";
          "browser.safebrowsing.allowOverride" = false;

          "network.prefetch-next" = false;
          "network.dns.disablePrefetch" = true;
          "network.predictor.enabled" = false;

          "browser.fixup.alternate.enabled" = false;
          "browser.urlbar.trimURLs" = false;

          "browser.contentblocking.category" = "strict";
          "privacy.partition.serviceWorkers" = true;
          "privacy.partition.always_partition_third_party_non_cookie_storage" = true;
          "privacy.partition.always_partition_third_party_non_cookie_storage.exempt_sessionstorage" = true;
          "privacy.resistFingerprinting" = true;
          "privacy.resistFingerprinting.block_mozAddonManager" = true;

          "app.normandy.enabled" = false;
          "app.normandy.api_url" = "";
        };

        extensions.packages = with pkgs.nur.repos.rycee.firefox-addons; [
          ublock-origin bitwarden rust-search-extension betterttv
        ];
      };
    };
  };
}
