{pkgs, config, ...}: {
  imports = [
    ../options.nix
  ];

  environment.systemPackages = with pkgs; [
    # Basic utilities
    zsh
    wget
    curl
    git
    vim

    htop

    linux-firmware
    linuxHeaders
  ];

  nix.settings.experimental-features = [
    "nix-command"
    "flakes"
  ];

  system.stateVersion = "25.05";

  boot = {
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = true;

    # kernelModules = [];
    kernelPackages = pkgs.linuxPackages_zen;
  };

  hardware = {
    enableAllFirmware = true;
    amdgpu.initrd.enable = true;
    graphics = {
      enable = true;
      enable32Bit = true;
    };
  };

  security = {
    polkit.enable = true;
    rtkit.enable = true;
  };

  fonts = {
    enableDefaultPackages = true;
    packages = with pkgs; [
      noto-fonts
      noto-fonts-cjk-sans
      noto-fonts-emoji
      liberation_ttf
      roboto
      roboto-mono
      twitter-color-emoji
      nerd-fonts.fira-code
      nerd-fonts.fira-mono
      unicode-emoji
      fira-sans
      font-awesome
      fira-mono
      fira-code
      material-icons
      source-sans
      source-code-pro
      pkgs.nur.repos.redpz.sf-mono
    ];
    fontconfig = {
      defaultFonts = {
        monospace = ["SF Mono" "Fira Mono" "Noto Mono"];
        serif = ["Liberation Serif" "Noto Serif"];
        sansSerif = ["Liberation Sans" "Noto Sans" "Roboto"];
        emoji = ["Twitter Color Emoji" "Noto Emoji"];
      };
    };
  };

  networking = {
    nameservers = ["1.1.1.1" "9.9.9.9"];

    wireless.iwd = {
      enable = true;
      settings = {
        Settings ={
          AutoConnect = true;
        };
      };
    };
  };

  time.timeZone = "Europe/Amsterdam";
  i18n.defaultLocale = "en_GB.UTF-8";

  console = {
    font = "Lat2-Terminus16";
    keyMap = "uk";
  };

  services = {
    qemuGuest.enable = config.vmGuest;
    spice-vdagentd.enable = config.vmGuest;

    connman = {
      enable = true;
      wifi.backend = "iwd"; # Use iwd for Wi-Fi management.
    };

    pipewire = {
      enable = true;
      pulse.enable = true;
      alsa.enable = true;
      alsa.support32Bit = true;
    };

    openssh = {
      enable = true;
      settings = {
        PasswordAuthentication = true; # Enable password authentication.
        PermitRootLogin = "yes"; # Allow root login (not recommended for production).
      };
    };

    libinput.enable = true;
  };
}
